==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FeatureGateSpecFluentImpl<A extends FeatureGateSpecFluent<A>> extends BaseFluent<A> implements FeatureGateSpecFluent<A>{
  public FeatureGateSpecFluentImpl() {
  }
  public FeatureGateSpecFluentImpl(FeatureGateSpec instance) {
    this.withCustomNoUpgrade(instance.getCustomNoUpgrade()); 
    this.withFeatureSet(instance.getFeatureSet()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private CustomFeatureGatesBuilder customNoUpgrade;
  private String featureSet;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCustomNoUpgrade instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomFeatureGates getCustomNoUpgrade() {
    return this.customNoUpgrade!=null ?this.customNoUpgrade.build():null;
  }
  public CustomFeatureGates buildCustomNoUpgrade() {
    return this.customNoUpgrade!=null ?this.customNoUpgrade.build():null;
  }
  public A withCustomNoUpgrade(CustomFeatureGates customNoUpgrade) {
    _visitables.get("customNoUpgrade").remove(this.customNoUpgrade);
    if (customNoUpgrade!=null){ this.customNoUpgrade= new CustomFeatureGatesBuilder(customNoUpgrade); _visitables.get("customNoUpgrade").add(this.customNoUpgrade);} else { this.customNoUpgrade = null; _visitables.get("customNoUpgrade").remove(this.customNoUpgrade); } return (A) this;
  }
  public Boolean hasCustomNoUpgrade() {
    return this.customNoUpgrade != null;
  }
  public FeatureGateSpecFluent.CustomNoUpgradeNested<A> withNewCustomNoUpgrade() {
    return new FeatureGateSpecFluentImpl.CustomNoUpgradeNestedImpl();
  }
  public FeatureGateSpecFluent.CustomNoUpgradeNested<A> withNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return new FeatureGateSpecFluentImpl.CustomNoUpgradeNestedImpl(item);
  }
  public FeatureGateSpecFluent.CustomNoUpgradeNested<A> editCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(getCustomNoUpgrade());
  }
  public FeatureGateSpecFluent.CustomNoUpgradeNested<A> editOrNewCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(getCustomNoUpgrade() != null ? getCustomNoUpgrade(): new CustomFeatureGatesBuilder().build());
  }
  public FeatureGateSpecFluent.CustomNoUpgradeNested<A> editOrNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return withNewCustomNoUpgradeLike(getCustomNoUpgrade() != null ? getCustomNoUpgrade(): item);
  }
  public String getFeatureSet() {
    return this.featureSet;
  }
  public A withFeatureSet(String featureSet) {
    this.featureSet=featureSet; return (A) this;
  }
  public Boolean hasFeatureSet() {
    return this.featureSet != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FeatureGateSpecFluentImpl that = (FeatureGateSpecFluentImpl) o;
    if (customNoUpgrade != null ? !customNoUpgrade.equals(that.customNoUpgrade) :that.customNoUpgrade != null) return false;
    if (featureSet != null ? !featureSet.equals(that.featureSet) :that.featureSet != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(customNoUpgrade,  featureSet,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (customNoUpgrade != null) { sb.append("customNoUpgrade:"); sb.append(customNoUpgrade + ","); }
    if (featureSet != null) { sb.append("featureSet:"); sb.append(featureSet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class CustomNoUpgradeNestedImpl<N> extends CustomFeatureGatesFluentImpl<FeatureGateSpecFluent.CustomNoUpgradeNested<N>> implements FeatureGateSpecFluent.CustomNoUpgradeNested<N>,Nested<N>{
    CustomNoUpgradeNestedImpl(CustomFeatureGates item) {
      this.builder = new CustomFeatureGatesBuilder(this, item);
    }
    CustomNoUpgradeNestedImpl() {
      this.builder = new CustomFeatureGatesBuilder(this);
    }
    CustomFeatureGatesBuilder builder;
    public N and() {
      return (N) FeatureGateSpecFluentImpl.this.withCustomNoUpgrade(builder.build());
    }
    public N endCustomNoUpgrade() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FeatureGateSpecFluentImpl<A extends FeatureGateSpecFluent<A>> extends BaseFluent<A> implements FeatureGateSpecFluent<A>{
  public FeatureGateSpecFluentImpl() {
  }
  public FeatureGateSpecFluentImpl(FeatureGateSpec instance) {
    if (instance != null) {
      this.withCustomNoUpgrade(instance.getCustomNoUpgrade());
      this.withFeatureSet(instance.getFeatureSet());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private CustomFeatureGatesBuilder customNoUpgrade;
  private String featureSet;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildCustomNoUpgrade instead.
   * @return The buildable object.
   */
  @Deprecated
  public CustomFeatureGates getCustomNoUpgrade() {
    return this.customNoUpgrade!=null ?this.customNoUpgrade.build():null;
  }
  public CustomFeatureGates buildCustomNoUpgrade() {
    return this.customNoUpgrade!=null ?this.customNoUpgrade.build():null;
  }
  public A withCustomNoUpgrade(CustomFeatureGates customNoUpgrade) {
    _visitables.get("customNoUpgrade").remove(this.customNoUpgrade);
    if (customNoUpgrade!=null){ this.customNoUpgrade= new CustomFeatureGatesBuilder(customNoUpgrade); _visitables.get("customNoUpgrade").add(this.customNoUpgrade);} else { this.customNoUpgrade = null; _visitables.get("customNoUpgrade").remove(this.customNoUpgrade); } return (A) this;
  }
  public Boolean hasCustomNoUpgrade() {
    return this.customNoUpgrade != null;
  }
  public FeatureGateSpecFluentImpl.CustomNoUpgradeNested<A> withNewCustomNoUpgrade() {
    return new FeatureGateSpecFluentImpl.CustomNoUpgradeNestedImpl();
  }
  public FeatureGateSpecFluentImpl.CustomNoUpgradeNested<A> withNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return new FeatureGateSpecFluentImpl.CustomNoUpgradeNestedImpl(item);
  }
  public FeatureGateSpecFluentImpl.CustomNoUpgradeNested<A> editCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(getCustomNoUpgrade());
  }
  public FeatureGateSpecFluentImpl.CustomNoUpgradeNested<A> editOrNewCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(getCustomNoUpgrade() != null ? getCustomNoUpgrade(): new CustomFeatureGatesBuilder().build());
  }
  public FeatureGateSpecFluentImpl.CustomNoUpgradeNested<A> editOrNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return withNewCustomNoUpgradeLike(getCustomNoUpgrade() != null ? getCustomNoUpgrade(): item);
  }
  public String getFeatureSet() {
    return this.featureSet;
  }
  public A withFeatureSet(String featureSet) {
    this.featureSet=featureSet; return (A) this;
  }
  public Boolean hasFeatureSet() {
    return this.featureSet != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeatureGateSpecFluentImpl that = (FeatureGateSpecFluentImpl) o;
    if (!java.util.Objects.equals(customNoUpgrade, that.customNoUpgrade)) return false;

    if (!java.util.Objects.equals(featureSet, that.featureSet)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(customNoUpgrade,  featureSet,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (customNoUpgrade != null) { sb.append("customNoUpgrade:"); sb.append(customNoUpgrade + ","); }
    if (featureSet != null) { sb.append("featureSet:"); sb.append(featureSet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class CustomNoUpgradeNestedImpl<N> extends CustomFeatureGatesFluentImpl<FeatureGateSpecFluentImpl.CustomNoUpgradeNested<N>> implements FeatureGateSpecFluentImpl.CustomNoUpgradeNested<N>,Nested<N>{
    CustomNoUpgradeNestedImpl(CustomFeatureGates item) {
      this.builder = new CustomFeatureGatesBuilder(this, item);
    }
    CustomNoUpgradeNestedImpl() {
      this.builder = new CustomFeatureGatesBuilder(this);
    }
    CustomFeatureGatesBuilder builder;
    public N and() {
      return (N) FeatureGateSpecFluentImpl.this.withCustomNoUpgrade(builder.build());
    }
    public N endCustomNoUpgrade() {
      return and();
    }
    
  }
  
}
